pub struct RiCircuitBreakerConfig {
pub consecutive_errors: u32,
pub interval: Duration,
pub base_ejection_time: Duration,
pub max_ejection_percent: f64,
}Fields
consecutive_errors: u32interval: Durationbase_ejection_time: Durationmax_ejection_percent: f64Trait Implementations
Sourceimpl Clone for RiCircuitBreakerConfig
impl Clone for RiCircuitBreakerConfig
Sourcefn clone(&self) -> RiCircuitBreakerConfig
fn clone(&self) -> RiCircuitBreakerConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RiCircuitBreakerConfig
impl Debug for RiCircuitBreakerConfig
Sourceimpl<'de> Deserialize<'de> for RiCircuitBreakerConfig
impl<'de> Deserialize<'de> for RiCircuitBreakerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'py> IntoPyObject<'py> for RiCircuitBreakerConfig
impl<'py> IntoPyObject<'py> for RiCircuitBreakerConfig
Sourcetype Target = RiCircuitBreakerConfig
type Target = RiCircuitBreakerConfig
The Python output type
Sourcetype Output = Bound<'py, <RiCircuitBreakerConfig as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <RiCircuitBreakerConfig as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for RiCircuitBreakerConfig
impl PyClass for RiCircuitBreakerConfig
Sourceimpl PyClassImpl for RiCircuitBreakerConfig
impl PyClassImpl for RiCircuitBreakerConfig
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<RiCircuitBreakerConfig>
type ThreadChecker = SendablePyClass<RiCircuitBreakerConfig>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for RiCircuitBreakerConfig
impl PyClassNewTextSignature for RiCircuitBreakerConfig
const TEXT_SIGNATURE: &'static str = "(consecutive_errors, max_ejection_percent)"
Sourceimpl PyMethods<RiCircuitBreakerConfig> for PyClassImplCollector<RiCircuitBreakerConfig>
impl PyMethods<RiCircuitBreakerConfig> for PyClassImplCollector<RiCircuitBreakerConfig>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for RiCircuitBreakerConfig
impl PyTypeInfo for RiCircuitBreakerConfig
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for RiCircuitBreakerConfig
impl Serialize for RiCircuitBreakerConfig
impl DerefToPyAny for RiCircuitBreakerConfig
impl ExtractPyClassWithClone for RiCircuitBreakerConfig