pub struct RiMatchCriteria {
pub path_prefix: Option<String>,
pub headers: HashMap<String, String>,
pub method: Option<String>,
pub query_parameters: HashMap<String, String>,
}Fields
path_prefix: Option<String>headers: HashMap<String, String>method: Option<String>query_parameters: HashMap<String, String>Trait Implementations
Sourceimpl Clone for RiMatchCriteria
impl Clone for RiMatchCriteria
Sourcefn clone(&self) -> RiMatchCriteria
fn clone(&self) -> RiMatchCriteria
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RiMatchCriteria
impl Debug for RiMatchCriteria
Sourceimpl<'de> Deserialize<'de> for RiMatchCriteria
impl<'de> Deserialize<'de> for RiMatchCriteria
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'py> IntoPyObject<'py> for RiMatchCriteria
impl<'py> IntoPyObject<'py> for RiMatchCriteria
Sourcetype Target = RiMatchCriteria
type Target = RiMatchCriteria
The Python output type
Sourcetype Output = Bound<'py, <RiMatchCriteria as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <RiMatchCriteria as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for RiMatchCriteria
impl PyClass for RiMatchCriteria
Sourceimpl PyClassImpl for RiMatchCriteria
impl PyClassImpl for RiMatchCriteria
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<RiMatchCriteria>
type ThreadChecker = SendablePyClass<RiMatchCriteria>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for RiMatchCriteria
impl PyClassNewTextSignature for RiMatchCriteria
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<RiMatchCriteria> for PyClassImplCollector<RiMatchCriteria>
impl PyMethods<RiMatchCriteria> for PyClassImplCollector<RiMatchCriteria>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for RiMatchCriteria
impl PyTypeInfo for RiMatchCriteria
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for RiMatchCriteria
impl Serialize for RiMatchCriteria
impl DerefToPyAny for RiMatchCriteria
impl ExtractPyClassWithClone for RiMatchCriteria